import {
  scaleLinear,
  scaleTime,
  scaleOrdinal,
  axisLeft,
  extent,
  line,
  flatGroup,
  schemeCategory10,
} from 'd3';
import {
  xAxis,
  yAxis,
  xAxisLabel,
  yAxisLabel,
} from '@python-monty/corey-responsive-axis';
import { axes } from './axes';
import { colorLegend } from './colorLegend';

// // Sample data for demonstration
// const data = [
//     { color: 'red', label: 'Category 1' },
//     { color: 'green', label: 'Category 2' },
//     { color: 'blue', label: 'Category 3' },
//     // Add more data as needed
// ];

// Dimensions and layout parameters

// // Create SVG element
// const svg = d3.select('body')
//     .append('svg')
//     .attr('width', svgWidth)
//     .attr('height', svgHeight);

// // Calculate number of items per column
// const itemsPerColumn = Math.ceil(data.length / 3);

// // Create legend items
// const legendItems = svg.selectAll('.legend-item')
//     .data(data)
//     .enter()
//     .append('g')
//     .attr('class', 'legend-item')
//     .attr('transform', (d, i) => {
//         const col = Math.floor(i / itemsPerColumn);
//         const row = i % itemsPerColumn;
//         const x = col * (columnWidth + columnPadding);
//         const y = row * (itemHeight + itemPadding);
//         return `translate(${x},${y})`;
//     });

// // Add colored rectangles
// legendItems.append('rect')
//     .attr('width', itemHeight)
//     .attr('height', itemHeight)
//     .attr('fill', d => d.color);

// // Add labels
// legendItems.append('text')
//     .attr('x', itemHeight + 5)
//     .attr('y', itemHeight / 2)
//     .attr('dy', '0.35em')
//     .text(d => d.label)
//     .style('font-size', '12px');

export const lineChart = (
  svg,
  {
    // filteredLineData,
    yearlyData,
    xValue,
    xAxisLabel,
    yAxisLabel,
    yValue,
    lineValue,
    yAxisLabelText,
    marginLeft,
    marginTop,
    marginRight,
    marginBottom,
    width,
    height,
    innerRectFill,
    colorLegendX,
    colorLegendY,
    colorLegendLabel,
    setHoveredValue,
    hoveredValue,
    yAxisLabelOffset,
    xAxisLabelOffset,
  },
) => {
  const xScale = scaleTime(extent(yearlyData, xValue), [
    marginLeft,
    width - marginRight,
  ]);

  const yScale = scaleLinear(extent(yearlyData, yValue), [
    height - marginBottom,
    marginTop,
  ]);

  const altColorScale = scaleOrdinal()
    .domain(yearlyData.map(lineValue))
    .range(schemeCategory10);

  svg.call(axes, {
    xScale,
    yScale,
    xAxisLabel,
    yAxisLabel,
    yAxisLabelOffset,
    xAxisLabelOffset,
  });

  const innerWidth = width - marginLeft - marginRight;
  const innerHeight = height - marginTop - marginBottom;

  svg
    .selectAll('rect')
    .data([null])
    .join('rect')
    .attr('x', marginLeft)
    .attr('y', marginTop)
    .attr('width', innerWidth)
    .attr('height', innerHeight)
    .attr('fill', innerRectFill);

  const lineGenerator = line(
    (d) => xScale(xValue(d)),
    (d) => yScale(yValue(d)),
  ).defined(yValue);

  const dataGrouped = flatGroup(yearlyData, (d) => {
    // return d.industryCode;
    return d.industryName;
  });

  // const legendWidth = 100;
  // const legendHeight = 200;
  const columnWidth = 178;
  const columnPadding = 55;
  const itemHeight = 10;
  const itemPadding = 3;
  const itemsPerColumn = Math.ceil(dataGrouped.length / 2);

  svg.call(colorLegend, {
    altColorScale,
    colorLegendLabel,
    colorLegendX,
    colorLegendY,
    setHoveredValue,
    hoveredValue,
    itemsPerColumn,
    columnWidth,
    columnPadding,
    itemHeight,
    itemPadding,
  });

  svg
    .selectAll('path.mark')
    .data(dataGrouped)
    .join('path')
    .attr('class', 'mark')
    .attr('fill', 'none')
    .attr('stroke', (d) => {
      return altColorScale(d[0]);
    })
    .style('stroke-width', 5)
    .attr('opacity', 0.5)
    .attr('d', (d) => lineGenerator(d[1]));
};
